跳到主要内容

ConnectError

搜索

枚举 ConnectError 

源代码
pub enum ConnectError {
    EndpointStopping,
    CidsExhausted,
    InvalidServerName(String),
    InvalidRemoteAddress(SocketAddr),
    NoDefaultClientConfig,
    UnsupportedVersion,
}
展开描述

用于创建新连接的参数中的错误

这些在执行任何 I/O 之前产生。

变体



EndpointStopping

端点无法再创建新连接

表示端点的某个必要组件已被丢弃或被禁用。



CidsExhausted

由于可用的 CID 空间不足,无法创建连接

可尝试使用更长的连接 ID



InvalidServerName(String)

给定的服务器名称格式错误



InvalidRemoteAddress(SocketAddr)

所提供的远端 SocketAddr 格式错误

例如尝试连接 0 端口,或使用了不匹配的地址族。



NoDefaultClientConfig

未设置默认的客户端配置

请使用 Endpoint::connect_with 来指定一个客户端配置。



UnsupportedVersion

本地端点不支持客户端配置中指定的 QUIC 版本

trait 实现

源代码

impl Clone for ConnectError

源代码

fn clone(&self) -> ConnectError

返回值的副本。 更多信息
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
源代码

impl Debug for ConnectError

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

使用给定的格式化器格式化此值。 更多信息
源代码

impl Display for ConnectError

源代码

fn fmt(&self, __formatter: &mut Formatter<'_>) -> Result<(), Error>

使用给定的格式化器格式化此值。 更多信息
源代码

impl Error for ConnectError

1.30.0 · 源代码

fn source(&self) -> Option<&(dyn Error + 'static)>

返回此错误的更底层来源(若有)。 更多信息
1.0.0 · 源代码

fn description(&self) -> &str

👎Deprecated since 1.42.0: use the Display impl or to_string()
1.0.0 · 源代码

fn cause(&self) -> Option<&dyn Error>

👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
源代码

fn provide<'a>(&'a self, request: &mut Request<'a>)

🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports. 更多信息
源代码

impl From<UnsupportedVersion> for ConnectError

源代码

fn from(_: UnsupportedVersion) -> ConnectError

从输入类型转换为此类型。
源代码

impl PartialEq for ConnectError

源代码

fn eq(&self, other: &ConnectError) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.
源代码

impl Eq for ConnectError

源代码

impl StructuralPartialEq for ConnectError

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回该参数。

源代码

impl<T> Instrument for T

源代码

fn instrument(self, span: Span) -> Instrumented<Self>

Instruments this type with the provided Span, returning an Instrumented wrapper. 更多信息
源代码

fn in_current_span(self) -> Instrumented<Self>

Instruments this type with the current Span, returning an Instrumented wrapper. 更多信息
源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换行为完全由 From<T> for U 的实现决定。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

The resulting type after obtaining ownership.
源代码

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
源代码

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

Converts the given value to a String. 更多信息
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

The type returned in the event of a conversion error.
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

The type returned in the event of a conversion error.
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。
源代码

impl<V, T> VZip<V> for T
where V: MultiLane<T>,

源代码

fn vzip(self) -> V

源代码

impl<T> WithSubscriber for T

源代码

fn with_subscriber<S>(self, subscriber: S) -> WithDispatch<Self>
where S: Into<Dispatch>,

Attaches the provided Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

fn with_current_subscriber(self) -> WithDispatch<Self>

Attaches the current default Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

impl<ST, DT> CastableFrom<ST, Initialized, Initialized> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<ST, DT> CastableFrom<ST, Uninit, Uninit> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<T> Read<Exclusive, BecauseExclusive> for T
where T: ?Sized,