跳到主要内容

Transmit

搜索

结构体 Transmit 

源代码
pub struct Transmit {
    pub destination: SocketAddr,
    pub ecn: Option<EcnCodepoint>,
    pub size: usize,
    pub segment_size: Option<usize>,
    pub src_ip: Option<IpAddr>,
}
展开描述

一个出站数据包

字段

destination: SocketAddr

该数据报应发送到的套接字

ecn: Option<EcnCodepoint>

在该包上设置的显式拥塞通知位

size: usize

已写入调用方提供的缓冲区的数据量

segment_size: Option<usize>

若本次传输包含多个数据报,则为分段大小。若本次传输仅包含单个数据报,则为 None

src_ip: Option<IpAddr>

该数据报的可选源 IP 地址

trait 实现

源代码

impl Debug for Transmit

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

使用给定的格式化器格式化此值。 更多信息

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回该参数。

源代码

impl<T> Instrument for T

源代码

fn instrument(self, span: Span) -> Instrumented<Self>

Instruments this type with the provided Span, returning an Instrumented wrapper. 更多信息
源代码

fn in_current_span(self) -> Instrumented<Self>

Instruments this type with the current Span, returning an Instrumented wrapper. 更多信息
源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换行为完全由 From<T> for U 的实现决定。

源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

The type returned in the event of a conversion error.
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

The type returned in the event of a conversion error.
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。
源代码

impl<V, T> VZip<V> for T
where V: MultiLane<T>,

源代码

fn vzip(self) -> V

源代码

impl<T> WithSubscriber for T

源代码

fn with_subscriber<S>(self, subscriber: S) -> WithDispatch<Self>
where S: Into<Dispatch>,

Attaches the provided Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

fn with_current_subscriber(self) -> WithDispatch<Self>

Attaches the current default Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

impl<ST, DT> CastableFrom<ST, Initialized, Initialized> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<ST, DT> CastableFrom<ST, Uninit, Uninit> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<T> Read<Exclusive, BecauseExclusive> for T
where T: ?Sized,