跳到主要内容

VarInt

搜索

结构体 VarInt 

源代码
pub struct VarInt(/* private fields */);
展开描述

一个小于 2^62 的整数

此类型的值适合编码为 QUIC 可变长整数。

实现

源代码

impl VarInt

源代码

pub const MAX: VarInt

可表示的最大值

源代码

pub const MAX_SIZE: usize = 8

编码后的最大长度

源代码

pub const fn from_u32(x: u32) -> VarInt

以不会失败的方式构造一个 VarInt

源代码

pub fn from_u64(x: u64) -> Result<VarInt, VarIntBoundsExceeded>

当且仅当 x < 2^62 时成功

源代码

pub const unsafe fn from_u64_unchecked(x: u64) -> VarInt

在不检查取值范围的情况下构造一个 VarInt

安全性

x 必须小于 2^62。

源代码

pub const fn into_inner(self) -> u64

取出底层整数值

trait 实现

源代码

impl Clone for VarInt

源代码

fn clone(&self) -> VarInt

返回值的副本。 更多信息
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
源代码

impl Codec for VarInt

源代码

fn decode<B>(r: &mut B) -> Result<VarInt, UnexpectedEnd>
where B: Buf,

如果缓冲区足够大,则从提供的缓冲区解码一个 Self
源代码

fn encode<B>(&self, w: &mut B)
where B: BufMut,

self 的编码追加到提供的缓冲区
源代码

impl Debug for VarInt

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

使用给定的格式化器格式化此值。 更多信息
源代码

impl Default for VarInt

源代码

fn default() -> VarInt

Returns the “default value” for a type. 更多信息
源代码

impl Display for VarInt

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

使用给定的格式化器格式化此值。 更多信息
源代码

impl From<StreamId> for VarInt

源代码

fn from(x: StreamId) -> VarInt

从输入类型转换为此类型。
源代码

impl From<VarInt> for IdleTimeout

源代码

fn from(inner: VarInt) -> IdleTimeout

从输入类型转换为此类型。
源代码

impl From<VarInt> for StreamId

源代码

fn from(v: VarInt) -> StreamId

从输入类型转换为此类型。
源代码

impl From<u16> for VarInt

源代码

fn from(x: u16) -> VarInt

从输入类型转换为此类型。
源代码

impl From<u32> for VarInt

源代码

fn from(x: u32) -> VarInt

从输入类型转换为此类型。
源代码

impl From<u8> for VarInt

源代码

fn from(x: u8) -> VarInt

从输入类型转换为此类型。
源代码

impl Hash for VarInt

源代码

fn hash<__H>(&self, state: &mut __H)
where __H: Hasher,

Feeds this value into the given Hasher. 更多信息
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 更多信息
源代码

impl Ord for VarInt

源代码

fn cmp(&self, other: &VarInt) -> Ordering

This method returns an Ordering between self and other. 更多信息
1.21.0 · 源代码

fn max(self, other: Self) -> Self
where Self: Sized,

Compares and returns the maximum of two values. 更多信息
1.21.0 · 源代码

fn min(self, other: Self) -> Self
where Self: Sized,

Compares and returns the minimum of two values. 更多信息
1.50.0 · 源代码

fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized,

Restrict a value to a certain interval. 更多信息
源代码

impl PartialEq for VarInt

源代码

fn eq(&self, other: &VarInt) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.
源代码

impl PartialOrd for VarInt

源代码

fn partial_cmp(&self, other: &VarInt) -> Option<Ordering>

若存在,此方法返回 selfother 值之间的排序关系。 更多信息
1.0.0 · 源代码

fn lt(&self, other: &Rhs) -> bool

测试小于(针对 selfother),供 < 运算符使用。 更多信息
1.0.0 · 源代码

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator. 更多信息
1.0.0 · 源代码

fn gt(&self, other: &Rhs) -> bool

Tests greater than (for self and other) and is used by the > operator. 更多信息
1.0.0 · 源代码

fn ge(&self, other: &Rhs) -> bool

Tests greater than or equal to (for self and other) and is used by the >= operator. 更多信息
源代码

impl TryFrom<u128> for VarInt

源代码

fn try_from(x: u128) -> Result<VarInt, VarIntBoundsExceeded>

当且仅当 x < 2^62 时成功

源代码

type Error = VarIntBoundsExceeded

The type returned in the event of a conversion error.
源代码

impl TryFrom<u64> for VarInt

源代码

fn try_from(x: u64) -> Result<VarInt, VarIntBoundsExceeded>

当且仅当 x < 2^62 时成功

源代码

type Error = VarIntBoundsExceeded

The type returned in the event of a conversion error.
源代码

impl TryFrom<usize> for VarInt

源代码

fn try_from(x: usize) -> Result<VarInt, VarIntBoundsExceeded>

当且仅当 x < 2^62 时成功

源代码

type Error = VarIntBoundsExceeded

The type returned in the event of a conversion error.
源代码

impl Copy for VarInt

源代码

impl Eq for VarInt

源代码

impl StructuralPartialEq for VarInt

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回该参数。

源代码

impl<T> Instrument for T

源代码

fn instrument(self, span: Span) -> Instrumented<Self>

Instruments this type with the provided Span, returning an Instrumented wrapper. 更多信息
源代码

fn in_current_span(self) -> Instrumented<Self>

Instruments this type with the current Span, returning an Instrumented wrapper. 更多信息
源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换行为完全由 From<T> for U 的实现决定。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

The resulting type after obtaining ownership.
源代码

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
源代码

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

Converts the given value to a String. 更多信息
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

The type returned in the event of a conversion error.
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

The type returned in the event of a conversion error.
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。
源代码

impl<V, T> VZip<V> for T
where V: MultiLane<T>,

源代码

fn vzip(self) -> V

源代码

impl<T> WithSubscriber for T

源代码

fn with_subscriber<S>(self, subscriber: S) -> WithDispatch<Self>
where S: Into<Dispatch>,

Attaches the provided Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

fn with_current_subscriber(self) -> WithDispatch<Self>

Attaches the current default Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

impl<ST, DT> CastableFrom<ST, Initialized, Initialized> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<ST, DT> CastableFrom<ST, Uninit, Uninit> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<T> Read<Exclusive, BecauseExclusive> for T
where T: ?Sized,